#ifndef AUDM_AFTEN_PARAM_H
#define AUDM_AFTEN_PARAM_H


struct AFTEN_encoderParam
{
  uint32_t        bitrate;
  ADM_mode        mode;
};

#endif
